<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <el-input size="default" v-model.trim="listQuery.searchParams.name" placeholder="请输入证书类型" style="max-width: 180px"> </el-input>
                <el-button size="default" type="primary" class="ml10" @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenDialogRef('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增
                </el-button>
            </div>
            <el-table :data="tableData.data" style="width: 100%">
                <el-table-column prop="name" label="证书类型" show-overflow-tooltip></el-table-column>
                <el-table-column prop="personCount" label="关联证书人员" show-overflow-tooltip>
                  <template #default="scope">
                    <el-button v-if="scope.row.personCount && scope.row.personCount>0" link type="primary" @click="openMembers('人员',scope.row)">{{scope.row.personCount}}</el-button>
                    <span v-else>0</span>
                  </template>
                </el-table-column>
                <el-table-column prop="unValidCount" label="三个月证书到期" show-overflow-tooltip>
                  <template #default="scope">
                    <el-button v-if="scope.row.unValidCount && scope.row.unValidCount>0" link type="danger" @click="openMembers('到期',scope.row)">{{scope.row.unValidCount}}</el-button>
                    <span v-else>0</span>
                  </template>
                </el-table-column>
<!--                <el-table-column prop="warnCount" label="历史预警信息" show-overflow-tooltip>-->
<!--                  <template #default="scope">-->
<!--                    <el-button v-if="scope.row.warnCount && scope.row.warnCount>0" link type="danger" @click="openMes(scope.row)">{{scope.row.warnCount}}</el-button>-->
<!--                    <span v-else>0</span>-->
<!--                  </template>-->
<!--                </el-table-column>-->
                <el-table-column label="操作" width="150">
                    <template #default="scope">
                        <el-button size="small" text type="primary" @click="onOpenDialogRef('修改', scope.row)">修改</el-button>
                        <el-button size="small" style="color: red" text type="primary" @click="onRowDel(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="page-position" :pager-count="5" :page-sizes="[10]" v-model:current-page="listQuery.pageIndex" background v-model:page-size="listQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="tableData.total"> </el-pagination>
            <br />
            <br />
        </el-card>
        <certificateDialog ref="certificateRef" @refreshCertList="initRoleTableData" />
        <certificate-member ref="certificateMemRef"></certificate-member>
        <messages ref="mesRef"></messages>
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import certificateDialog from '/@/views/system/certificate/component/certificateDialog.vue'
import certificateMember from '/@/views/system/certificate/component/certificateMember.vue'
import messages from '/@/views/system/certificate/component/messages.vue'
import { certApi } from '/@/api/systemManage/certificate';
import { useMenuApi } from '/@/api/systemManage/menu';
import { Session } from '/@/utils/storage';
import { initBackEndControlRoutes } from '/@/router/backEnd';
import {useUserInfo} from "/@/stores/userInfo";
import {storeToRefs} from "pinia";

// 定义接口来定义对象的类型
interface TableData {
    roleName: string;
    roleSign: string;
    describe: string;
    sort: number;
    status: boolean;
    createTime: string;
}
interface TableDataState {
    tableData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
    };
  listQuery: {
    pageIndex: number
    pageSize: number
    searchParams: {
      name: string
    }
  };
}

export default defineComponent({
    name: 'certificate',
    components: {messages, certificateMember, certificateDialog },
    setup() {
        const userInfo = useUserInfo();
        const { userInfos } = storeToRefs(userInfo);
        const certificateRef = ref();
        const certificateMemRef = ref();
        const mesRef = ref();
        const state = reactive<TableDataState>({
            tableData: {
                data: [],
                total: 0,
                loading: false,
            },
          listQuery: {
            pageIndex: 1,
            pageSize: 10,
            searchParams: {
              name:''
            }
          }
        });
        // 初始化表格数据
        const initRoleTableData = async () => {
            let res = await certApi().getCerttypeList(state.listQuery);
            if (res.data.code === '200') {
                state.tableData.data = res.data.data;
                state.tableData.total = res.data.total
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        const onOpenDialogRef = (type: string, value: any) => {
            certificateRef.value.openDialog(type, value);
        };

        const openMembers = (type: string, value: any) => {
          certificateMemRef.value.openDialog(type,value)
        }

      const openMes = (value: any) => {
        mesRef.value.openDialog(value)
      }
        const onRowDel = (row: any) => {
            ElMessageBox.confirm(`此操作将永久删除角色名称：“${row.name}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await certApi().deleteCerttype(row.id);
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initRoleTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };
        const handleSearch = () => {
            state.listQuery.pageIndex = 1
            initRoleTableData();
        };

      // 分页改变
      const onHandleSizeChange = (val: number) => {
        state.listQuery.pageSize = val;
        initRoleTableData();
      };
      // 分页改变
      const onHandleCurrentChange = (val: number) => {
        state.listQuery.pageIndex = val;
        initRoleTableData();
      };
        // 页面加载时
        onMounted(() => {
            initRoleTableData();
        });
        return {
            onRowDel,
            handleSearch,
            certificateRef,
          certificateMemRef,
          mesRef,
            onOpenDialogRef,
          openMembers,
            openMes,
            initRoleTableData,
            onHandleSizeChange,
            onHandleCurrentChange,
            ...toRefs(state)
        };
    }
});
</script>
